var react = require('react');

var usePageWidth = function usePageWidth() {
  var _useState = react.useState(window.innerWidth),
      pageWidth = _useState[0],
      setPageWidth = _useState[1];

  var updateDimensions = function updateDimensions() {
    setPageWidth(window.innerWidth);
  };

  react.useEffect(function () {
    window.addEventListener('resize', updateDimensions);
    return function () {
      window.removeEventListener('resize', updateDimensions);
    };
  }, [pageWidth]);
  return pageWidth;
};

var useString = function useString(text) {
  return text;
};

// A type of promise-like that resolves synchronously and supports only one observer

const _iteratorSymbol = /*#__PURE__*/ typeof Symbol !== "undefined" ? (Symbol.iterator || (Symbol.iterator = Symbol("Symbol.iterator"))) : "@@iterator";

const _asyncIteratorSymbol = /*#__PURE__*/ typeof Symbol !== "undefined" ? (Symbol.asyncIterator || (Symbol.asyncIterator = Symbol("Symbol.asyncIterator"))) : "@@asyncIterator";

// Asynchronously call a function and send errors to recovery continuation
function _catch(body, recover) {
	try {
		var result = body();
	} catch(e) {
		return recover(e);
	}
	if (result && result.then) {
		return result.then(void 0, recover);
	}
	return result;
}

var randomJokeApi = 'https://api.jsonbin.io/b/5eda3e691f9e4e578817d386';

var errorMessage = 'Upps...Something went wrong, please try later.';

var getRandomIndex = function getRandomIndex(array) {
  return Math.floor(Math.random() * array.length);
};

var useHelloRomanJoke = function useHelloRomanJoke() {
  var _useState = react.useState(),
      randomQuestion = _useState[0],
      setRandomQuestion = _useState[1];

  var _useState2 = react.useState(),
      randomAnswer = _useState2[0],
      setRandomAnswer = _useState2[1];

  var _useState3 = react.useState(),
      error = _useState3[0],
      setError = _useState3[1];

  var generateRandomJoke = function generateRandomJoke(jokes) {
    var _jokes$getRandomIndex = jokes[getRandomIndex(jokes)],
        question = _jokes$getRandomIndex.question,
        answer = _jokes$getRandomIndex.answer;
    setRandomQuestion(question);
    setRandomAnswer(answer);
  };

  var fetchJokes = function fetchJokes() {
    try {
      var _temp2 = _catch(function () {
        return Promise.resolve(fetch(randomJokeApi)).then(function (data) {
          return Promise.resolve(data.json()).then(function (_ref) {
            var jokes = _ref.jokes;
            generateRandomJoke(jokes);
          });
        });
      }, function () {
        setError(errorMessage);
      });

      return Promise.resolve(_temp2 && _temp2.then ? _temp2.then(function () {}) : void 0);
    } catch (e) {
      return Promise.reject(e);
    }
  };

  react.useEffect(function () {
    fetchJokes();
  }, []);
  return [randomQuestion, randomAnswer, error];
};

var useUnsplash = function useUnsplash(_ref) {
  var user = _ref.user,
      _ref$random = _ref.random,
      random = _ref$random === void 0 ? true : _ref$random,
      width = _ref.width,
      height = _ref.height;

  var _useState = react.useState(),
      randomImage = _useState[0],
      setRandomImage = _useState[1];

  var _useState2 = react.useState(),
      error = _useState2[0],
      setError = _useState2[1];

  var fetchImage = function fetchImage() {
    try {
      try {
        var apiLink = "https://source.unsplash.com/" + (user ? "user/" + user : random ? 'random' : null) + "/" + (width || height ? width + "x" + height : null);
        setRandomImage(apiLink);
      } catch (_unused) {
        setError(errorMessage);
      }

      return Promise.resolve();
    } catch (e) {
      return Promise.reject(e);
    }
  };

  react.useEffect(function () {
    fetchImage();
  }, []);
  return [randomImage, error];
};

var Events;

(function (Events) {
  Events["MOUSEDOWN"] = "mousedown";
  Events["TOUCHSTART"] = "touchstart";
})(Events || (Events = {}));

var useClickOutside = function useClickOutside(ref, handler) {
  react.useEffect(function () {
    var listener = function listener(event) {
      if (!ref.current || ref.current.contains(event.target)) {
        return;
      }

      handler(event);
    };

    document.addEventListener('mousedown', listener);
    document.addEventListener('touchstart', listener);
    return function () {
      document.removeEventListener('mousedown', listener);
      document.removeEventListener('touchstart', listener);
    };
  }, [ref, handler]);
};

exports.useClickOutside = useClickOutside;
exports.useHelloRomanJoke = useHelloRomanJoke;
exports.usePageWidth = usePageWidth;
exports.useString = useString;
exports.useUnsplash = useUnsplash;
//# sourceMappingURL=index.js.map
